@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/geometry_utils.h $
-// $Id: geometry_utils.h 57cf9e0 2022-04-19T14:55:15+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/geometry_utils.h $
+// $Id: include/CGAL/Alpha_wrap_3/internal/geometry_utils.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pierre Alliez
@@ -40,16 +40,16 @@ struct Orientation_of_circumcenter
   }
 };
 
-template <typename Dt>
+template <typename Tr>
 bool
-less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
-                                        const typename Dt::Facet& fh,
-                                        const Dt& dt)
+less_squared_radius_of_min_empty_sphere(typename Tr::Geom_traits::FT sq_alpha,
+                                        const typename Tr::Facet& fh,
+                                        const Tr& tr)
 {
-  using Cell_handle = typename Dt::Cell_handle;
-  using Point = typename Dt::Point;
+  using Cell_handle = typename Tr::Cell_handle;
+  using Point = typename Tr::Point;
 
-  using CK = typename Dt::Geom_traits;
+  using CK = typename Tr::Geom_traits;
   using Exact_kernel = typename Exact_kernel_selector<CK>::Exact_kernel;
   using Approximate_kernel = Simple_cartesian<Interval_nt_advanced>;
   using C2A = Cartesian_converter<CK, Approximate_kernel>;
@@ -61,21 +61,30 @@ less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
 
   Orientation_of_circumcenter orientation_of_circumcenter;
 
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+  std::cout << "Checking for traversability of facet" << std::endl;
+#endif
+
   const Cell_handle c = fh.first;
   const int ic = fh.second;
   const Cell_handle n = c->neighbor(ic);
 
-  const Point& p1 = dt.point(c, Dt::vertex_triple_index(ic,0));
-  const Point& p2 = dt.point(c, Dt::vertex_triple_index(ic,1));
-  const Point& p3 = dt.point(c, Dt::vertex_triple_index(ic,2));
+  const Point& p1 = tr.point(c, Tr::vertex_triple_index(ic,0));
+  const Point& p2 = tr.point(c, Tr::vertex_triple_index(ic,1));
+  const Point& p3 = tr.point(c, Tr::vertex_triple_index(ic,2));
 
   // This is not actually possible in the context of alpha wrapping, but keeping it for genericity
   // and because it does not cost anything.
-  if(dt.is_infinite(n))
+  if(tr.is_infinite(n))
   {
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+    std::cerr << "Warning: computing less_squared_radius_of_min_empty_sphere() with an infinite neighbor?" << std::endl;
+#endif
+    CGAL_assertion(!tr.is_infinite(c));
+
     Orientation ori = orientation_of_circumcenter(p1, p2, p3,
-                                                  dt.point(c, 0), dt.point(c, 1),
-                                                  dt.point(c, 2), dt.point(c, 3));
+                                                  tr.point(c, 0), tr.point(c, 1),
+                                                  tr.point(c, 2), tr.point(c, 3));
 
     if(ori == POSITIVE)
     {
@@ -84,18 +93,22 @@ less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
     }
     else
     {
-      Comparison_result cr = compare_squared_radius(dt.point(c, 0), dt.point(c, 1),
-                                                    dt.point(c, 2), dt.point(c, 3),
+      Comparison_result cr = compare_squared_radius(tr.point(c, 0), tr.point(c, 1),
+                                                    tr.point(c, 2), tr.point(c, 3),
                                                     sq_alpha);
       return cr == LARGER;
     }
   }
 
-  if(dt.is_infinite(c))
+  if(tr.is_infinite(c))
   {
     Orientation ori = orientation_of_circumcenter(p1, p2, p3,
-                                                  dt.point(n, 0), dt.point(n, 1),
-                                                  dt.point(n, 2), dt.point(n, 3));
+                                                  tr.point(n, 0), tr.point(n, 1),
+                                                  tr.point(n, 2), tr.point(n, 3));
+
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+    std::cout << "Cell 'c' is infinite; Orientation: " << ori << std::endl;
+#endif
 
     if(ori == NEGATIVE)
     {
@@ -104,8 +117,8 @@ less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
     }
     else
     {
-      Comparison_result cr = compare_squared_radius(dt.point(n, 0), dt.point(n, 1),
-                                                    dt.point(n, 2), dt.point(n, 3),
+      Comparison_result cr = compare_squared_radius(tr.point(n, 0), tr.point(n, 1),
+                                                    tr.point(n, 2), tr.point(n, 3),
                                                     sq_alpha);
       return cr == LARGER;
     }
@@ -113,40 +126,40 @@ less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
 
   // both c and n are finite
   if(orientation_of_circumcenter(p1, p2, p3,
-                                 dt.point(c, 0), dt.point(c, 1), dt.point(c, 2), dt.point(c, 3)) !=
+                                 tr.point(c, 0), tr.point(c, 1), tr.point(c, 2), tr.point(c, 3)) !=
      orientation_of_circumcenter(p1, p2, p3,
-                                 dt.point(n, 0), dt.point(n, 1), dt.point(n, 2), dt.point(n, 3)))
+                                 tr.point(n, 0), tr.point(n, 1), tr.point(n, 2), tr.point(n, 3)))
   {
     Comparison_result cr = compare_squared_radius(p1, p2, p3, sq_alpha);
 #ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
     std::cout << "dual crosses the face; CR: "
-              << typename Dt::Geom_traits().compute_squared_radius_3_object()(p1, p2, p3)
+              << typename Tr::Geom_traits().compute_squared_radius_3_object()(p1, p2, p3)
               << " sq alpha " << sq_alpha << std::endl;
 #endif
     return cr == LARGER;
   }
   else
   {
-    Comparison_result cr = compare_squared_radius(dt.point(c, 0), dt.point(c, 1),
-                                                  dt.point(c, 2), dt.point(c, 3),
+    Comparison_result cr = compare_squared_radius(tr.point(c, 0), tr.point(c, 1),
+                                                  tr.point(c, 2), tr.point(c, 3),
                                                   sq_alpha);
 #ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
     std::cout << "dual does not cross the face; CR(c): "
-              << typename Dt::Geom_traits().compute_squared_radius_3_object()(dt.point(c, 0), dt.point(c, 1),
-                                                                              dt.point(c, 2), dt.point(c, 3))
+              << typename Tr::Geom_traits().compute_squared_radius_3_object()(tr.point(c, 0), tr.point(c, 1),
+                                                                              tr.point(c, 2), tr.point(c, 3))
               << " sq alpha " << sq_alpha << std::endl;
 #endif
 
     if(cr != LARGER)
       return false;
 
-    cr = compare_squared_radius(dt.point(n, 0), dt.point(n, 1),
-                                dt.point(n, 2), dt.point(n, 3),
+    cr = compare_squared_radius(tr.point(n, 0), tr.point(n, 1),
+                                tr.point(n, 2), tr.point(n, 3),
                                 sq_alpha);
 #ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
     std::cout << "dual does not cross the face; CR(n): "
-              << typename Dt::Geom_traits().compute_squared_radius_3_object()(dt.point(n, 0), dt.point(n, 1),
-                                                                              dt.point(n, 2), dt.point(n, 3))
+              << typename Tr::Geom_traits().compute_squared_radius_3_object()(tr.point(n, 0), tr.point(n, 1),
+                                                                              tr.point(n, 2), tr.point(n, 3))
               << " sq alpha " << sq_alpha << std::endl;
 #endif
 
@@ -154,6 +167,100 @@ less_squared_radius_of_min_empty_sphere(typename Dt::Geom_traits::FT sq_alpha,
   }
 }
 
+template <typename Tr>
+typename Tr::Geom_traits::FT
+smallest_squared_radius_3(const typename Tr::Facet& fh,
+                          const Tr& tr)
+{
+  using Cell_handle = typename Tr::Cell_handle;
+  using Point = typename Tr::Point;
+  using FT = typename Tr::Geom_traits::FT;
+
+  using CK = typename Tr::Geom_traits;
+  using Exact_kernel = typename Exact_kernel_selector<CK>::Exact_kernel;
+  using Approximate_kernel = Simple_cartesian<Interval_nt_advanced>;
+  using C2A = Cartesian_converter<CK, Approximate_kernel>;
+  using C2E = typename Exact_kernel_selector<CK>::C2E;
+
+  using Orientation_of_circumcenter = Filtered_predicate<Orientation_of_circumcenter<Exact_kernel>,
+                                                         Orientation_of_circumcenter<Approximate_kernel>,
+                                                         C2E, C2A>;
+
+  Orientation_of_circumcenter orientation_of_circumcenter;
+
+  auto squared_radius = tr.geom_traits().compute_squared_radius_3_object();
+
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+  std::cout << "Computing circumradius of facet" << std::endl;
+#endif
+
+  CGAL_precondition(!tr.is_infinite(fh));
+
+  const Cell_handle c = fh.first;
+  const int ic = fh.second;
+  const Cell_handle n = c->neighbor(ic);
+
+  const Point& p1 = tr.point(c, Tr::vertex_triple_index(ic,0));
+  const Point& p2 = tr.point(c, Tr::vertex_triple_index(ic,1));
+  const Point& p3 = tr.point(c, Tr::vertex_triple_index(ic,2));
+
+  // This is not actually possible in the context of alpha wrapping, but keeping it for genericity
+  // and because it does not cost anything.
+  if(tr.is_infinite(n))
+  {
+    CGAL_assertion(!tr.is_infinite(c));
+
+    Orientation ori = orientation_of_circumcenter(p1, p2, p3,
+                                                  tr.point(c, 0), tr.point(c, 1),
+                                                  tr.point(c, 2), tr.point(c, 3));
+    if(ori == POSITIVE)
+      return squared_radius(p1, p2, p3);
+    else
+      return squared_radius(tr.point(c, 0), tr.point(c, 1), tr.point(c, 2), tr.point(c, 3));
+  }
+
+  if(tr.is_infinite(c))
+  {
+    Orientation ori = orientation_of_circumcenter(p1, p2, p3,
+                                                  tr.point(n, 0), tr.point(n, 1),
+                                                  tr.point(n, 2), tr.point(n, 3));
+
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+    std::cout << "Cell 'c' is infinite; Orientation: " << ori << std::endl;
+#endif
+
+    if(ori == NEGATIVE)
+      return squared_radius(p1, p2, p3);
+    else
+      return squared_radius(tr.point(n, 0), tr.point(n, 1), tr.point(n, 2), tr.point(n, 3));
+  }
+
+  // both c and n are finite
+  if(orientation_of_circumcenter(p1, p2, p3,
+                                 tr.point(c, 0), tr.point(c, 1), tr.point(c, 2), tr.point(c, 3)) !=
+     orientation_of_circumcenter(p1, p2, p3,
+                                 tr.point(n, 0), tr.point(n, 1), tr.point(n, 2), tr.point(n, 3)))
+  {
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+    std::cout << "dual crosses the face; CR: " << squared_radius(p1, p2, p3) << std::endl;
+#endif
+
+    return squared_radius(p1, p2, p3);
+  }
+  else
+  {
+    const FT cr = squared_radius(tr.point(c, 0), tr.point(c, 1), tr.point(c, 2), tr.point(c, 3));
+    const FT cnr = squared_radius(tr.point(n, 0), tr.point(n, 1), tr.point(n, 2), tr.point(n, 3));
+
+#ifdef CGAL_AW3_DEBUG_TRAVERSABILITY
+    std::cout << "dual does not cross the face; CR(c): " << cr << " CRn: " << cnr << std::endl;
+#endif
+
+    return (CGAL::min)(cr, cnr);
+  }
+}
+
+
 } // namespace internal
 } // namespace Alpha_wraps_3
 } // namespace CGAL
