@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/Generalized_barycentric_coordinates_2.h $
-// $Id: Generalized_barycentric_coordinates_2.h be147c5 2022-04-28T07:58:57+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Barycentric_coordinates_2/include/CGAL/Barycentric_coordinates_2/Generalized_barycentric_coordinates_2.h $
+// $Id: include/CGAL/Barycentric_coordinates_2/Generalized_barycentric_coordinates_2.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,7 +24,7 @@
 #include <CGAL/Barycentric_coordinates_2/barycentric_enum_2.h>
 
 // Boost headers.
-#include <boost/optional.hpp>
+#include <optional>
 
 // CGAL namespace.
 namespace CGAL {
@@ -118,7 +118,7 @@ public:
     /// `CGAL::Barycentric_coordinates::PRECISE` - default slow algorithm, which is as precise as possible and
     /// `CGAL::Barycentric_coordinates::FAST` - fast algorithm, which is less precise but much faster.
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> operator()(const Point_2 &query_point, OutputIterator output, Query_point_location query_point_location = UNSPECIFIED_LOCATION, Type_of_algorithm type_of_algorithm = PRECISE)
+        inline std::optional<OutputIterator> operator()(const Point_2 &query_point, OutputIterator output, Query_point_location query_point_location = UNSPECIFIED_LOCATION, Type_of_algorithm type_of_algorithm = PRECISE)
     {
         return coordinates_2(query_point, output, query_point_location, type_of_algorithm);
     }
@@ -129,7 +129,7 @@ public:
     /// \pre The provided query point belongs to the polygon's boundary.
     /// \pre (0 <= index) && (index < number of the polygon's vertices).
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> compute_on_edge(const Point_2 &query_point, const int index, OutputIterator output) const
+        inline std::optional<OutputIterator> compute_on_edge(const Point_2 &query_point, const int index, OutputIterator output) const
     {
         return coordinates_on_boundary_2(query_point, index, output);
     }
@@ -139,7 +139,7 @@ public:
     ///
     /// \pre (0 <= index) && (index < number of the polygon's vertices).
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> compute_on_vertex(const int index, OutputIterator output) const
+        inline std::optional<OutputIterator> compute_on_vertex(const int index, OutputIterator output) const
     {
         return coordinates_on_vertex_2(index, output);
     }
@@ -149,7 +149,7 @@ public:
     ///
     /// \pre The provided query point belongs to the polygon's interior, excluding the boundary.
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> compute_weights(const Point_2 &query_point, OutputIterator output)
+        inline std::optional<OutputIterator> compute_weights(const Point_2 &query_point, OutputIterator output)
     {
         return weights_2(query_point, output);
     }
@@ -183,7 +183,7 @@ public:
     // This function accepts a container of the type <a href="https://en.cppreference.com/w/cpp/container/vector">`std::vector`</a>
     // and returns an iterator of the type <a href="https://en.cppreference.com/w/cpp/iterator/back_insert_iterator">`std::back_insert_iterator`</a>
     // that is placed past-the-end of the resulting sequence of coordinate values.
-    inline boost::optional<std::back_insert_iterator<std::vector<FT> > > operator()(const Point_2 &query_point, std::vector<FT> &output_vector, Query_point_location query_point_location = UNSPECIFIED_LOCATION, Type_of_algorithm type_of_algorithm = PRECISE)
+    inline std::optional<std::back_insert_iterator<std::vector<FT> > > operator()(const Point_2 &query_point, std::vector<FT> &output_vector, Query_point_location query_point_location = UNSPECIFIED_LOCATION, Type_of_algorithm type_of_algorithm = PRECISE)
     {
         output_vector.reserve(output_vector.size() + number_of_vertices);
         typedef typename std::back_insert_iterator<std::vector<FT> > OutputIterator;
@@ -198,7 +198,7 @@ public:
     //
     // \pre The provided query point belongs to the polygon's boundary.
     // \pre (0 <= index) && (index < number of the polygon's vertices).
-    inline boost::optional<std::back_insert_iterator<std::vector<FT> > > compute_on_edge(const Point_2 &query_point, const int index, std::vector<FT> &output_vector) const
+    inline std::optional<std::back_insert_iterator<std::vector<FT> > > compute_on_edge(const Point_2 &query_point, const int index, std::vector<FT> &output_vector) const
     {
         output_vector.reserve(output_vector.size() + number_of_vertices);
         typedef typename std::back_insert_iterator<std::vector<FT> > OutputIterator;
@@ -212,7 +212,7 @@ public:
     // that is placed past-the-end of the resulting sequence of coordinate values.
     //
     // \pre (0 <= index) && (index < number of the polygon's vertices).
-    inline boost::optional<std::back_insert_iterator<std::vector<FT> > > compute_on_vertex(const int index, std::vector<FT> &output_vector) const
+    inline std::optional<std::back_insert_iterator<std::vector<FT> > > compute_on_vertex(const int index, std::vector<FT> &output_vector) const
     {
         output_vector.reserve(output_vector.size() + number_of_vertices);
         typedef typename std::back_insert_iterator<std::vector<FT> > OutputIterator;
@@ -226,7 +226,7 @@ public:
     // that is placed past-the-end of the resulting sequence of weight values.
     //
     // \pre The provided query point belongs to the polygon's interior, excluding the boundary.
-    inline boost::optional<std::back_insert_iterator<std::vector<FT> > > compute_weights(const Point_2 &query_point, std::vector<FT> &output_vector)
+    inline std::optional<std::back_insert_iterator<std::vector<FT> > > compute_weights(const Point_2 &query_point, std::vector<FT> &output_vector)
     {
         output_vector.reserve(output_vector.size() + number_of_vertices);
         typedef typename std::back_insert_iterator<std::vector<FT> > OutputIterator;
@@ -283,7 +283,7 @@ private:
 
     // Compute weights on the bounded side of the polygon - see precondition.
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> weights_2(const Point_2 &query_point, OutputIterator &output)
+        inline std::optional<OutputIterator> weights_2(const Point_2 &query_point, OutputIterator &output)
     {
         // This is the only global precondition on the computation of weights.
         CGAL_precondition( CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits) == CGAL::ON_BOUNDED_SIDE );
@@ -295,7 +295,7 @@ private:
 
     // Compute coordinates at any point in the plane.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_2(const Point_2 &query_point, OutputIterator &output, const Query_point_location query_point_location, const Type_of_algorithm type_of_algorithm)
+        std::optional<OutputIterator> coordinates_2(const Point_2 &query_point, OutputIterator &output, const Query_point_location query_point_location, const Type_of_algorithm type_of_algorithm)
     {
         // Determine a location of the current query point provided by the user.
         switch(query_point_location)
@@ -324,13 +324,13 @@ private:
         // Pointer cannot be here. Something went wrong.
         const bool query_point_location_failure = true;
         CGAL_postcondition( !query_point_location_failure );
-        if(!query_point_location_failure) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(!query_point_location_failure) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // Compute coordinates at any point in the plane with unspecified location.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_unspecified_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
+        std::optional<OutputIterator> coordinates_unspecified_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
     {
         // Determine a global location of the current query point.
         switch(CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits))
@@ -355,15 +355,15 @@ private:
         // Pointer cannot be here. Something went wrong.
         const bool query_point_location_failure = true;
         CGAL_postcondition( !query_point_location_failure );
-        if(!query_point_location_failure) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(!query_point_location_failure) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // COORDINATES ON BOUNDED SIDE.
 
     // Compute coordinates on the bounded side of the polygon - precise or fast.
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> coordinates_on_bounded_side_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
+        inline std::optional<OutputIterator> coordinates_on_bounded_side_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
     {
         CGAL_precondition( CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits) == CGAL::ON_BOUNDED_SIDE );
 
@@ -374,7 +374,7 @@ private:
 
     // Compute coordinates along the boundary of the polygon with beforehand known index of the edge to which the query point belongs.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_on_boundary_2(const Point_2 &query_point, const int index, OutputIterator &output) const
+        std::optional<OutputIterator> coordinates_on_boundary_2(const Point_2 &query_point, const int index, OutputIterator &output) const
     {
         CGAL_precondition( CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits) == CGAL::ON_BOUNDARY );
         CGAL_precondition( (0 <= index) && (index < int(number_of_vertices)) );
@@ -393,7 +393,7 @@ private:
 
             // Compute segment coordinates along the chosen edge with the index = `index`.
             Segment_coordinates_2<Traits> segment_coordinates(vertex[index], vertex[index+1]);
-            boost::optional<OutputIterator> success = segment_coordinates(query_point, output);
+            std::optional<OutputIterator> success = segment_coordinates(query_point, output);
             ++output;
 
             for(int i = index + 1; i < last; ++i) {
@@ -402,20 +402,20 @@ private:
             }
 
             // Return coordinates.
-            if(success) return boost::optional<OutputIterator>(output);
-            else return boost::optional<OutputIterator>();
+            if(success) return std::optional<OutputIterator>(output);
+            else return std::optional<OutputIterator>();
         }
 
         // Pointer cannot be here. Something went wrong.
         const bool coordinates_on_boundary_failure = true;
         CGAL_postcondition( !coordinates_on_boundary_failure );
-        if(!coordinates_on_boundary_failure) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(!coordinates_on_boundary_failure) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // Compute coordinates along the boundary of the polygon without beforehand known index of the edge to which the query point belongs.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_on_boundary_2(const Point_2 &query_point, OutputIterator &output) const
+        std::optional<OutputIterator> coordinates_on_boundary_2(const Point_2 &query_point, OutputIterator &output) const
     {
         CGAL_precondition( CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits) == CGAL::ON_BOUNDARY );
 
@@ -435,7 +435,7 @@ private:
 
                     // Compute segment coordinates along the edge with the query point.
                     Segment_coordinates_2<Traits> segment_coordinates(vertex[index], vertex[index+1]);
-                    boost::optional<OutputIterator> success = segment_coordinates(query_point, output);
+                    std::optional<OutputIterator> success = segment_coordinates(query_point, output);
                     if(success) status = true;
                     ++output;
                     break;
@@ -452,20 +452,20 @@ private:
             }
 
             // Return coordinates.
-            if(status == true) return boost::optional<OutputIterator>(output);
-            else return boost::optional<OutputIterator>();
+            if(status == true) return std::optional<OutputIterator>(output);
+            else return std::optional<OutputIterator>();
         }
 
         // Pointer cannot be here. Something went wrong.
         const bool coordinates_on_boundary_failure = true;
         CGAL_postcondition( !coordinates_on_boundary_failure );
-        if(!coordinates_on_boundary_failure) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(!coordinates_on_boundary_failure) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // Compute coordinates for a query point lying on the last edge of the polygon.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_on_last_edge_2(const Point_2 &query_point, const int last, OutputIterator &output) const
+        std::optional<OutputIterator> coordinates_on_last_edge_2(const Point_2 &query_point, const int last, OutputIterator &output) const
     {
         // Some convenient typedefs.
         typedef std::vector<FT> Coordinate_vector;
@@ -478,7 +478,7 @@ private:
 
         // Compute segment coordinates along the last edge of the polygon.
         Segment_coordinates_2<Traits> segment_coordinates(vertex[last], vertex[0]);
-        boost::optional<Vector_insert_iterator> success = segment_coordinates(query_point, std::back_inserter(coordinate));
+        std::optional<Vector_insert_iterator> success = segment_coordinates(query_point, std::back_inserter(coordinate));
 
         // Store all the coordinate values.
         // All the values are zeros apart from those corresponding to the first and the last vertices of the polygon.
@@ -492,15 +492,15 @@ private:
         ++output;
 
         // Return computed coordinates.
-        if(success) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(success) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // COORDINATES AT VERTEX.
 
     // Compute coordinates for a query point lying at one of the polygon's vertices with beforehand known vertex's index.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_on_vertex_2(const int index, OutputIterator &output) const
+        std::optional<OutputIterator> coordinates_on_vertex_2(const int index, OutputIterator &output) const
     {
         CGAL_precondition( (0 <= index) && (index < int(number_of_vertices)) );
 
@@ -519,12 +519,12 @@ private:
         }
 
         // Return coordinates.
-        return boost::optional<OutputIterator>(output);
+        return std::optional<OutputIterator>(output);
     }
 
     // Compute coordinates for a query point lying at one of the polygon's vertices without beforehand known vertex's index.
     template<class OutputIterator>
-        boost::optional<OutputIterator> coordinates_on_vertex_2(const Point_2 &query_point, OutputIterator &output) const
+        std::optional<OutputIterator> coordinates_on_vertex_2(const Point_2 &query_point, OutputIterator &output) const
     {
         int index = -1;
         CGAL_precondition( is_query_point_at_vertex(query_point, index) );
@@ -554,15 +554,15 @@ private:
 
         // Return coordinates.
         CGAL_postcondition( !coordinates_on_vertex_failure );
-        if(!coordinates_on_vertex_failure) return boost::optional<OutputIterator>(output);
-        else return boost::optional<OutputIterator>();
+        if(!coordinates_on_vertex_failure) return std::optional<OutputIterator>(output);
+        else return std::optional<OutputIterator>();
     }
 
     // COORDINATES ON UNBOUNDED SIDE.
 
     // Compute coordinates on the unbounded side of the polygon - precise or fast.
     template<class OutputIterator>
-        inline boost::optional<OutputIterator> coordinates_on_unbounded_side_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
+        inline std::optional<OutputIterator> coordinates_on_unbounded_side_2(const Point_2 &query_point, OutputIterator &output, const Type_of_algorithm type_of_algorithm)
     {
         CGAL_precondition( CGAL::bounded_side_2(vertex.begin(), vertex.end(), query_point, barycentric_traits) == CGAL::ON_UNBOUNDED_SIDE );
 
