@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Stream_support/include/CGAL/IO/Istream_iterator.h $
-// $Id: Istream_iterator.h 580a1ef 2020-05-22T15:31:50+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Stream_support/include/CGAL/IO/Istream_iterator.h $
+// $Id: include/CGAL/IO/Istream_iterator.h e13ef800cb7 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -28,7 +28,7 @@ The class `Istream_iterator` is an input iterator adaptor for the
 input stream class `Stream` and value type `T`. It is particularly
 useful for classes that are similar but not compatible to `std::istream`.
 
-\cgalModels `InputIterator`
+\cgalModels{InputIterator}
 */
 template <class T, class Stream>
 class Istream_iterator
