@@ -3,13 +3,18 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Partition_2/include/CGAL/Partition_2/Rotation_tree_2_impl.h $
-// $Id: Rotation_tree_2_impl.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Partition_2/include/CGAL/Partition_2/Rotation_tree_2_impl.h $
+// $Id: include/CGAL/Partition_2/Rotation_tree_2_impl.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Susan Hert <hert@mpi-sb.mpg.de>
 
+#ifndef CGAL_PARTITION_2_ROTATION_TREE_2_IMPL_H
+#define CGAL_PARTITION_2_ROTATION_TREE_2_IMPL_H
+
+#include <CGAL/license/Partition_2.h>
+
 #include <iostream>
 
 namespace CGAL {
@@ -130,3 +135,5 @@ std::ostream& operator<<(std::ostream& os, const Rotation_tree_2<Traits>& tree)
 }
 
 }
+
+#endif // CGAL_PARTITION_2_ROTATION_TREE_2_IMPL_H
