@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_2.h $
-// $Id: Periodic_4_hyperbolic_Delaunay_triangulation_2.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_2.h $
+// $Id: include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_2.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Iordan Iordanov
@@ -165,15 +165,11 @@ public:
     spatial_sort(points.begin(), points.end(), geom_traits());
 
     Face_handle f;
-    int cnt = 0;
-    int cnt_good = 0;
     for(typename std::vector<Point>::const_iterator p=points.begin(), end = points.end(); p != end; ++p)
     {
-      ++cnt;
       Vertex_handle v = insert(*p, f);
       if(v != Vertex_handle())
       {
-        ++cnt_good;
         f = v->face();
       }
     }
@@ -271,7 +267,7 @@ public:
 
   Point get_dummy_point(int i) const
   {
-    CGAL_triangulation_precondition(0 <= i && i <= static_cast<int>(dummy_points.size()));
+    CGAL_precondition(0 <= i && i <= static_cast<int>(dummy_points.size()));
     return dummy_points[i]();
   }
 
@@ -543,7 +539,7 @@ remove(Vertex_handle v)
       int nidx = 0;
       if(nbf->neighbor(1) == nb) nidx = 1;
       if(nbf->neighbor(2) == nb) nidx = 2;
-      CGAL_triangulation_assertion(nbf->neighbor(nidx) == nb);
+      CGAL_assertion(nbf->neighbor(nidx) == nb);
 
       bdry_nbrs.insert(Edge_neighbor(e, Neighbor_pair(nbf, nidx)));
       bdry_verts.push_back(nb->vertex(ccw(idx)));
@@ -596,8 +592,6 @@ remove(Vertex_handle v)
 
     Nbr_history failsafe;
 
-    int internb = 0;
-    int bdrynb = 0;
     for(std::size_t i=0; i<new_f.size(); ++i)
     {
       for(int k=0; k< 3; k++)
@@ -616,14 +610,13 @@ remove(Vertex_handle v)
             Nbr_entry side1(nbf, nbidx);
             Nbr_entry side2(nbf->neighbor(nbidx), nbf->neighbor(nbidx)->index(nbf));
 
-            CGAL_triangulation_assertion(side1.first->neighbor(side1.second) == side2.first);
-            CGAL_triangulation_assertion(side2.first->neighbor(side2.second) == side1.first);
+            CGAL_assertion(side1.first->neighbor(side1.second) == side2.first);
+            CGAL_assertion(side2.first->neighbor(side2.second) == side1.first);
 
             Nbr_pair hist(side1, side2);
             failsafe.push_back(hist);
 
             tds().set_adjacency(nbf, nbidx, new_f[i], k);
-            bdrynb++;
             break;
           }
         }
@@ -641,7 +634,6 @@ remove(Vertex_handle v)
                  new_f[i]->vertex(cw(k))  == new_f[l]->vertex(ccw(j)))
               {
                 tds().set_adjacency(new_f[i], k, new_f[l], j);
-                internb++;
                 break;
               }
             }
@@ -680,7 +672,7 @@ remove(Vertex_handle v)
                 tds().delete_face(new_f[rit]);
               }
 
-              CGAL_triangulation_assertion(this->is_valid(true));
+              CGAL_assertion(this->is_valid(true));
 
               return false;
             }
@@ -712,7 +704,7 @@ remove(Vertex_handle v)
 
     tds().delete_vertex(v);
 
-    CGAL_triangulation_assertion(this->is_valid(true));
+    CGAL_assertion(this->is_valid(true));
 
     return true;
   }
