@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Polyhedron/include/CGAL/Polyhedron_incremental_builder_3.h $
-// $Id: Polyhedron_incremental_builder_3.h eed54a0 2022-11-15T18:45:39+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Polyhedron/include/CGAL/Polyhedron_incremental_builder_3.h $
+// $Id: include/CGAL/Polyhedron_incremental_builder_3.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -73,7 +73,7 @@ protected:
     bool                      first_vertex;
     bool                      last_vertex;
 
-    CGAL_assertion_code( int check_protocoll;)  // use to check protocoll.
+    CGAL_assertion_code( int check_protocoll;)  // use to check_protocoll.
     // states for checking: 0 = created, 1 = constructing, 2 = make face.
 
     // Implement the vertex_to_edge_map either with an array or
