@@ -2,15 +2,18 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Triangulation_2/include/CGAL/boost/graph/properties_Regular_triangulation_2.h $
-// $Id: properties_Regular_triangulation_2.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Triangulation_2/include/CGAL/boost/graph/properties_Regular_triangulation_2.h $
+// $Id: include/CGAL/boost/graph/properties_Regular_triangulation_2.h e13ef800cb7 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Mael Rouxel-Labbé
 
 #ifndef CGAL_PROPERTIES_REGULAR_TRIANGULATION_2_H
 #define CGAL_PROPERTIES_REGULAR_TRIANGULATION_2_H
 
+#include <CGAL/license/Triangulation_2.h>
+
+
 #include <CGAL/Regular_triangulation_2.h>
 
 #define CGAL_2D_TRIANGULATION_TEMPLATE_PARAMETERS typename GT, typename TDS
